import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1

Page {
    id: page

    property variant location

    function selectDay(){
        var date= new Date();
        var today;
        today = date.getFullYear()+'-';
        today += ((date.getMonth()<9)?"0":"")+(date.getMonth()+1)+'-';
        today += ((date.getDate()<10)?"0":"")+date.getDate();
        //today = "2015-05-28";

        for (var i=0; i<=openModel.count; i++){
            var d = openModel.model.get(i);
            if(d.value >= today){
                days.positionViewAtIndex(i,ListView.SnapPosition);
                break;
            }
        }
    }

    ListModel{
        id: locationModel

        ListElement{
            name: "Mensa Uni"
            value: "Mensa"
        }
        ListElement{
            name: "Cafeteria B"
            value: "CB"
        }
        ListElement{
            name: "Bistro"
            value: "Bistro"
        }
        ListElement{
            name: "Uni West"
            value: "West"
        }
        ListElement{
            name: "Hochschule"
            value: "Prittwitzstr"
        }
        ListElement{
            name: "Southside"
            value: "$Burgerbar"
        }
        ListElement{
            name: "WestsideDiner"
            value: "$Diner"
        }
    }

    Component.onCompleted: {
        location = locationModel.get(0);
    }


    SelectionDialog{
        id: selLocation
        titleText: "Einrichtung"
        model: locationModel

        onSelectedIndexChanged: {
            location = model.get(selectedIndex);
        }
    }


    Rectangle{
        id: header
        width: parent.width
        height: 70
        color: "#7D9AAA"
        Label {
            id:headerCaption
            elide: Text.ElideRight
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            text: location.name
            horizontalAlignment: Text.AlignHCenter

            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 28
            }

            MouseArea{
                anchors.fill: parent
                onClicked: selLocation.open();
            }
        }

        Image{
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            anchors.margins: 10
            source: "image://theme/icon-m-common-combobox-arrow"

        }

    }

    ListView{
        id:days
        anchors.bottom: parent.bottom
        anchors.top: header.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        boundsBehavior: Flickable.StopAtBounds
        orientation: ListView.Horizontal
        snapMode: ListView.SnapOneItem;
        clip: true
        //anchors.margins: 10

        model: openModel.model;

        delegate: ListView{
            width: page.width
            anchors.bottom: parent.bottom
            anchors.top: parent.top
            anchors.margins: 10
            spacing: 15;

            model: mp.model

            delegate: speise
            focus: true

            Mensaplan{
                id: mp
                date: modelData
                json: openModel.json
                location: page.location.value
            }

            header: Component{
                Text{
                    text: formatDate(modelData)
                    //font: UiConstants.GroupHeaderFont
                    font.pixelSize: 28
                    height: UiConstants.GroupHeaderHeight
                    horizontalAlignment: Text.AlignHCenter
                    width: parent.width
                    color: "white"
                }
            }

        }

    }



    Oeffnung{
        id: openModel
        location: page.location.value
        onJsonChanged: selectDay()
    }

    SpeiseDelegate{
        id:speise
    }


    function formatDate(ds){
        var dow=["Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag"];
        var dow_en=["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
        if(ds.indexOf("-") == -1)
            return dow[dow_en.indexOf(ds)];

        var parts = ds.split("-");
        var date = new Date();
        date.setFullYear(parts[0]);
        date.setMonth(parts[1]-1);
        date.setDate(parts[2]);
        var s = dow[date.getDay()]+", "+date.getDate()+"."+(date.getMonth()+1)+"."+date.getFullYear();
        return s;
    }

    function kw(){
        var Datum=new Date();
        var DoDat=donnerstag(Datum);
        var kwjahr=DoDat.getFullYear();
        var DoKW1=donnerstag(new Date(kwjahr,0,4));
        return Math.floor(1.5+(DoDat.getTime()-DoKW1.getTime())/86400000/7)
    }

}


